from setuptools import setup
setup(
    name='messandger_da',
    version='0.2',
    packages = ['server', 'history', 'sender'],
    install_requires=[],
    python_requires=">=3.11",
    author="DavidYdin",
    author_email="David.2280@yandex.ru"
)